@@ -8,15 +8,11 @@
 #include <math.h>
 #include <string.h>
 #include <float.h>
-#ifdef __APPLE__
-#include <malloc/malloc.h>
-#else
-#include <malloc.h>
-#endif
+#include <stdlib.h>
 #include "dogleg.h"
 
-#if (CHOLMOD_VERSION > (CHOLMOD_VER_CODE(2,2)))
-#include <suitesparse/cholmod_function.h>
+#if (CHOLMOD_VERSION > (CHOLMOD_VER_CODE(2,2))) && (CHOLMOD_VERSION < (CHOLMOD_VER_CODE(4,0)))
+#include <cholmod_function.h>
 #endif
 
 
@@ -1132,9 +1128,11 @@ static void set_cholmod_options(cholmod_common* cc)
   // I want all output to go to STDERR, not STDOUT
 #if (CHOLMOD_VERSION <= (CHOLMOD_VER_CODE(2,2)))
   cc->print_function = cholmod_error_callback;
-#else
+#elif (CHOLMOD_VERSION < (CHOLMOD_VER_CODE(4,0)))
   CHOLMOD_FUNCTION_DEFAULTS ;
   CHOLMOD_FUNCTION_PRINTF(cc) = cholmod_error_callback;
+#else
+  SuiteSparse_config_printf_func_set(cholmod_error_callback);
 #endif
 }
 
